@@ -9,21 +9,21 @@ import argparse
 """
 
 parser = argparse.ArgumentParser('helper命令行传入参数 解析器', )
+parser.add_argument('-d', '--project_root_dir', type=str, )   # 你的项目的根目录
 parser.add_argument('-s', '--start_shell_str', type=str, )
 parser.add_argument('-n', '--script_name', type=str, )
 command_args = parser.parse_args()  # type:argparse.Namespace
 
 start_shell_str = command_args.start_shell_str
 script_name = command_args.script_name
-
+project_root_dir = command_args.project_root_dir
 
 def restart(args=None):
-    kill_str = f'''ps -aux|grep {script_name} |grep -v grep|awk '{{print $2}}' |xargs kill -9;'''
-    subprocess.getstatusoutput('git pull')
+    os.system('git pull')
+    kill_str = f'''ps -aux|grep {script_name} |grep -v grep|grep -v auto_restart_when_git_changed |grep -v  auto_restart_tool|awk '{{print $2}}' |xargs kill -9;'''
     os.system(kill_str)
-    print(1111)
-    threading.Thread(target=os.system, args=(start_shell_str,)).start()
-    print(2222)
+    start_shell_str_full = f''' cd {project_root_dir};export PYTHONPATH=./:$PYTHONPATH;{start_shell_str}'''
+    threading.Thread(target=os.system, args=(start_shell_str_full,)).start()
     while True:
         time.sleep(20)
         try:
@@ -37,9 +37,9 @@ def restart(args=None):
             print(e)
             break
         # subprocess.getstatusoutput(cmd_str)
-        print('git内容更新了，执行语句：', kill_str, start_shell_str)
+        print('git内容更新了，执行语句：', kill_str, start_shell_str_full)
         os.system(kill_str)
-        threading.Thread(target=os.system, args=(start_shell_str,)).start()
+        threading.Thread(target=os.system, args=(start_shell_str_full,)).start()
 
 
 if __name__ == '__main__':
